@@ -306,6 +306,10 @@ class MaskedImaging(abstract_dataset.AbstractMaskedDataset):
                         pixel_scale_interpolation_grid=self.pixel_scale_interpolation_grid
                     )
 
+    @property
+    def dataset(self):
+        return self.imaging
+
     @property
     def data(self):
         return self.image
