@@ -41,6 +41,10 @@ class FitDataset:
         self.model_data = model_data
         self.inversion = inversion
 
+    @property
+    def name(self):
+        return self.masked_dataset.dataset.name
+
     @property
     def mask(self):
         return self.masked_dataset.mask
