@@ -11,34 +11,34 @@ from autoarray import exc
 class TestCoordinates:
     def test__central_pixel__depends_on_shape_pixel_scale_and_origin(self):
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(0.1, 0.1)
         )
         assert mask.geometry.central_pixel_coordinates == (1, 1)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(4, 4)), pixel_scales=(0.1, 0.1)
         )
         assert mask.geometry.central_pixel_coordinates == (1.5, 1.5)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(5, 3)),
             pixel_scales=(0.1, 0.1),
             origin=(1.0, 2.0),
         )
         assert mask.geometry.central_pixel_coordinates == (2.0, 1.0)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(2.0, 1.0)
         )
         assert mask.geometry.central_pixel_coordinates == (1, 1)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(4, 4)), pixel_scales=(2.0, 1.0)
         )
         assert mask.geometry.central_pixel_coordinates == (1.5, 1.5)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(5, 3)),
             pixel_scales=(2.0, 1.0),
             origin=(1.0, 2.0),
@@ -54,7 +54,7 @@ class TestCoordinates:
             ]
         )
 
-        mask = aa.mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.mask_centre == (0.0, 0.0)
 
@@ -66,7 +66,7 @@ class TestCoordinates:
             ]
         )
 
-        mask = aa.mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.mask_centre == (0.0, 0.5)
 
@@ -78,7 +78,7 @@ class TestCoordinates:
             ]
         )
 
-        mask = aa.mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.mask_centre == (0.5, 0.0)
 
@@ -90,7 +90,7 @@ class TestCoordinates:
             ]
         )
 
-        mask = aa.mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.mask_centre == (0.0, -0.5)
 
@@ -102,7 +102,7 @@ class TestCoordinates:
             ]
         )
 
-        mask = aa.mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.mask_centre == (-0.5, 0.0)
 
@@ -114,117 +114,117 @@ class TestCoordinates:
             ]
         )
 
-        mask = aa.mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.mask_centre == (-0.5, -0.5)
 
     def test__pixel_grid__y_and_x_ticks(self):
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(0.5, 0.5)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-0.75, -0.25, 0.25, 0.75]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(6, 3)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-3.0, -1.0, 1.0, 3.0]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 1)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(0.5, 0.5)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-0.75, -0.25, 0.25, 0.75]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 6)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-3.0, -1.0, 1.0, 3.0]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(1, 3)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 5.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(0.5, 5.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-0.75, -0.25, 0.25, 0.75]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(6, 3)), pixel_scales=(1.0, 5.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-3.0, -1.0, 1.0, 3.0]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 6)), pixel_scales=(1.0, 5.0)
         )
         assert mask.geometry.yticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(5.0, 1.0)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-1.5, -0.5, 0.5, 1.5]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(5.0, 0.5)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-0.75, -0.25, 0.25, 0.75]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 6)), pixel_scales=(5.0, 1.0)
         )
         assert mask.geometry.xticks == pytest.approx(
             np.array([-3.0, -1.0, 1.0, 3.0]), 1e-3
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(6, 3)), pixel_scales=(5.0, 1.0)
         )
         assert mask.geometry.xticks == pytest.approx(
@@ -243,7 +243,7 @@ class TestGrids:
             shape_2d=(4, 7), pixel_scales=(0.56, 0.56), sub_size=1
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(4, 7)), pixel_scales=(0.56, 0.56)
         )
         mask[0, 0] = True
@@ -254,7 +254,7 @@ class TestGrids:
             mask.geometry.unmasked_grid.mask == np.full(fill_value=False, shape=(4, 7))
         ).all()
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 1.0)
         )
 
@@ -277,14 +277,14 @@ class TestGrids:
             shape_2d=(4, 7), pixel_scales=(0.8, 0.56), sub_size=1
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(4, 7)), pixel_scales=(0.8, 0.56)
         )
 
         assert mask.geometry.unmasked_grid.in_1d == pytest.approx(grid_1d_util, 1e-4)
         assert mask.geometry.unmasked_grid.in_2d == pytest.approx(grid_2d_util, 1e-4)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 2.0)
         )
 
@@ -305,7 +305,7 @@ class TestGrids:
             shape_2d=(4, 7), pixel_scales=(0.56, 0.56), origin=(1.0, 3.0), sub_size=1
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(4, 7)),
             pixel_scales=(0.56, 0.56),
             origin=(1.0, 3.0),
@@ -317,7 +317,7 @@ class TestGrids:
             shape_2d=(4, 7), pixel_scales=(0.56, 0.56), origin=(-1.0, -4.0), sub_size=1
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(4, 7)),
             pixel_scales=(0.56, 0.56),
             origin=(-1.0, -4.0),
@@ -329,7 +329,7 @@ class TestGrids:
             shape_2d=(4, 7), pixel_scales=(0.8, 0.56), origin=(1.0, 2.0), sub_size=1
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(4, 7)),
             pixel_scales=(0.8, 0.56),
             origin=(1.0, 2.0),
@@ -341,7 +341,7 @@ class TestGrids:
             shape_2d=(4, 7), pixel_scales=(0.8, 0.56), origin=(-1.0, -4.0), sub_size=1
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(4, 7)),
             pixel_scales=(0.8, 0.56),
             origin=(-1.0, -4.0),
@@ -351,7 +351,7 @@ class TestGrids:
 
     def test__masked_grids_1d(self):
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 1.0)
         )
 
@@ -372,7 +372,7 @@ class TestGrids:
             )
         ).all()
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 1.0)
         )
         mask[1, 1] = True
@@ -393,7 +393,7 @@ class TestGrids:
             )
         ).all()
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array([[False, True], [True, False], [True, False]]),
             pixel_scales=(1.0, 1.0),
             origin=(3.0, -2.0),
@@ -419,7 +419,7 @@ class TestGrids:
             ]
         )
 
-        mask = aa.mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.edge_grid.in_1d[0:11] == pytest.approx(
             np.array(
@@ -455,7 +455,7 @@ class TestGrids:
             ]
         )
 
-        mask = aa.mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
+        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0))
 
         assert mask.geometry.border_grid.in_1d[0:11] == pytest.approx(
             np.array(
@@ -477,7 +477,7 @@ class TestGrids:
         )
 
     def test__masked_sub_grid(self):
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)),
             pixel_scales=(1.0, 1.0),
             sub_size=1,
@@ -500,7 +500,7 @@ class TestGrids:
             )
         ).all()
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)),
             pixel_scales=(1.0, 1.0),
             sub_size=2,
@@ -530,7 +530,7 @@ class TestGrids:
             )
         ).all()
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)),
             pixel_scales=(1.0, 1.0),
             sub_size=1,
@@ -553,7 +553,7 @@ class TestGrids:
             )
         ).all()
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array([[False, True], [True, False], [True, False]]),
             pixel_scales=(1.0, 1.0),
             sub_size=5,
@@ -580,7 +580,7 @@ class TestGrids:
             ]
         )
 
-        mask = aa.mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0), sub_size=2)
+        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0), sub_size=2)
 
         assert (
             mask.geometry.sub_border_grid_1d
@@ -599,7 +599,7 @@ class TestGrids:
             ]
         )
 
-        mask = aa.mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0), sub_size=2)
+        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=(1.0, 1.0), sub_size=2)
 
         assert (
             mask.geometry.sub_border_grid_1d
@@ -621,7 +621,7 @@ class TestGrids:
 class TestArcsecToPixel:
     def test__pixel_coordinates_from_arcsec_coordinates(self):
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 2.0)
         )
 
@@ -638,7 +638,7 @@ class TestArcsecToPixel:
             scaled_coordinates=(-1.0, 1.0)
         ) == (1, 1)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(3.0, 3.0)
         )
 
@@ -672,7 +672,7 @@ class TestArcsecToPixel:
 
     def test__pixel_coordinates_from_arcsec_coordinates__arcsec_are_pixel_corners(self):
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 2.0)
         )
 
@@ -731,7 +731,7 @@ class TestArcsecToPixel:
     def test__pixel_coordinates_from_arcsec_coordinates___arcsec_are_pixel_centres__nonzero_centre(
         self
     ):
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)),
             pixel_scales=(2.0, 2.0),
             origin=(1.0, 1.0),
@@ -750,7 +750,7 @@ class TestArcsecToPixel:
             scaled_coordinates=(0.0, 2.0)
         ) == (1, 1)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)),
             pixel_scales=(3.0, 3.0),
             origin=(3.0, 3.0),
@@ -787,7 +787,7 @@ class TestArcsecToPixel:
     def test__pixel_coordinates_from_arcsec_coordinates__arcsec_are_pixel_corners__nonzero_centre(
         self
     ):
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)),
             pixel_scales=(2.0, 2.0),
             origin=(1.0, 1.0),
@@ -845,10 +845,98 @@ class TestArcsecToPixel:
             scaled_coordinates=(-0.99, 2.99)
         ) == (1, 1)
 
+    def test__scaled_coordinates_from_pixel_coordinates___scaled_are_pixel_centres__nonzero_centre(
+        self
+    ):
+        mask = aa.Mask.manual(
+            mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(3.0, 3.0)
+        )
+
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(0, 0)
+        ) == (3.0, -3.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(0, 1)
+        ) == (3.0, 0.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(0, 2)
+        ) == (3.0, 3.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(1, 0)
+        ) == (0.0, -3.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(1, 1)
+        ) == (0.0, 0.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(1, 2)
+        ) == (0.0, 3.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(2, 0)
+        ) == (-3.0, -3.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(2, 1)
+        ) == (-3.0, 0.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(2, 2)
+        ) == (-3.0, 3.0)
+
+        mask = aa.Mask.manual(
+            mask_2d=np.full(fill_value=False, shape=(2, 2)),
+            pixel_scales=(2.0, 2.0),
+            origin=(1.0, 1.0),
+        )
+
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(0, 0)
+        ) == (2.0, 0.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(0, 1)
+        ) == (2.0, 2.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(1, 0)
+        ) == (0.0, 0.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(1, 1)
+        ) == (0.0, 2.0)
+
+        mask = aa.Mask.manual(
+            mask_2d=np.full(fill_value=False, shape=(3, 3)),
+            pixel_scales=(3.0, 3.0),
+            origin=(3.0, 3.0),
+        )
+
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(0, 0)
+        ) == (6.0, 0.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(0, 1)
+        ) == (6.0, 3.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(0, 2)
+        ) == (6.0, 6.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(1, 0)
+        ) == (3.0, 0.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(1, 1)
+        ) == (3.0, 3.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(1, 2)
+        ) == (3.0, 6.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(2, 0)
+        ) == (0.0, 0.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(2, 1)
+        ) == (0.0, 3.0)
+        assert mask.geometry.scaled_coordinates_from_pixel_coordinates(
+            pixel_coordinates=(2, 2)
+        ) == (0.0, 6.0)
+
 
 class TestGridConversions:
     def test__grid_pixels_from_grid_arcsec(self):
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 4.0)
         )
 
@@ -868,7 +956,7 @@ class TestGridConversions:
 
     def test__grid_pixel_centres_1d_from_grid_arcsec_1d__same_as_grid_util(self):
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 2.0)
         )
 
@@ -886,7 +974,7 @@ class TestGridConversions:
 
         assert (grid_pixels == grid_pixels_util).all()
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(7.0, 2.0)
         )
 
@@ -905,7 +993,7 @@ class TestGridConversions:
         assert (grid_pixels == grid_pixels_util).all()
 
     def test__grid_pixel_indexes_1d_from_grid_arcsec_1d__same_as_grid_util(self):
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 2.0)
         )
 
@@ -923,7 +1011,7 @@ class TestGridConversions:
 
         assert (grid_pixel_indexes == grid_pixel_indexes_util).all()
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 4.0)
         )
 
@@ -942,7 +1030,7 @@ class TestGridConversions:
         assert (grid_pixels == grid_pixels_util).all()
 
     def test__grid_arcsec_1d_from_grid_pixels_1d__same_as_grid_util(self):
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 2.0)
         )
 
@@ -960,7 +1048,7 @@ class TestGridConversions:
 
         assert (grid_pixels == grid_pixels_util).all()
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)), pixel_scales=(2.0, 2.0)
         )
 
@@ -978,7 +1066,7 @@ class TestGridConversions:
         assert (grid_pixels == grid_pixels_util).all()
 
     def test__pixel_grid__grids_with_nonzero_centres__same_as_grid_util(self):
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)),
             pixel_scales=(2.0, 2.0),
             origin=(1.0, 2.0),
@@ -1042,7 +1130,7 @@ class TestGridConversions:
             grid_1d=np.array([[1.0, -2.0], [1.0, 2.0], [-1.0, -2.0], [-1.0, 2.0]])
         )
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(2, 2)),
             pixel_scales=(2.0, 1.0),
             origin=(1.0, 2.0),
@@ -1101,57 +1189,57 @@ class TestGridConversions:
 
 class TestZoomCentreAndOffet:
     def test__odd_sized_false_mask__centre_is_0_0__pixels_from_centre_are_0_0(self):
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 3)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (1.0, 1.0)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(5, 5)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (2.0, 2.0)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(3, 5)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (1.0, 2.0)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(5, 3)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (2.0, 1.0)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
     def test__even_sized_false_mask__centre_is_0_0__pixels_from_centre_are_0_0(self):
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(4, 4)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (1.5, 1.5)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(6, 6)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (2.5, 2.5)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(4, 6)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (1.5, 2.5)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.full(fill_value=False, shape=(6, 4)), pixel_scales=(1.0, 1.0)
         )
         assert mask.geometry._zoom_centre == (2.5, 1.5)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
     def test__mask_is_single_false__extraction_centre_is_central_pixel(self):
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [[False, True, True], [True, True, True], [True, True, True]]
             ),
@@ -1160,7 +1248,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (0, 0)
         assert mask.geometry._zoom_offset_pixels == (-1, -1)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [[True, True, False], [True, True, True], [True, True, True]]
             ),
@@ -1169,7 +1257,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (0, 2)
         assert mask.geometry._zoom_offset_pixels == (-1, 1)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [[True, True, True], [True, True, True], [False, True, True]]
             ),
@@ -1178,7 +1266,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (2, 0)
         assert mask.geometry._zoom_offset_pixels == (1, -1)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [[True, True, True], [True, True, True], [True, True, False]]
             ),
@@ -1187,7 +1275,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (2, 2)
         assert mask.geometry._zoom_offset_pixels == (1, 1)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [[True, False, True], [True, True, True], [True, True, True]]
             ),
@@ -1196,7 +1284,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (0, 1)
         assert mask.geometry._zoom_offset_pixels == (-1, 0)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [[True, True, True], [False, True, True], [True, True, True]]
             ),
@@ -1205,7 +1293,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (1, 0)
         assert mask.geometry._zoom_offset_pixels == (0, -1)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [[True, True, True], [True, True, False], [True, True, True]]
             ),
@@ -1214,7 +1302,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (1, 2)
         assert mask.geometry._zoom_offset_pixels == (0, 1)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [[True, True, True], [True, True, True], [True, False, True]]
             ),
@@ -1224,7 +1312,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_offset_pixels == (1, 0)
 
     def test__mask_is_x2_false__extraction_centre_is_central_pixel(self):
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [[False, True, True], [True, True, True], [True, True, False]]
             ),
@@ -1233,7 +1321,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (1, 1)
         assert mask.geometry._zoom_offset_pixels == (0, 0)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [[False, True, True], [True, True, True], [False, True, True]]
             ),
@@ -1242,7 +1330,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (1, 0)
         assert mask.geometry._zoom_offset_pixels == (0, -1)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [[False, True, False], [True, True, True], [True, True, True]]
             ),
@@ -1251,7 +1339,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (0, 1)
         assert mask.geometry._zoom_offset_pixels == (-1, 0)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [[False, False, True], [True, True, True], [True, True, True]]
             ),
@@ -1261,7 +1349,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_offset_pixels == (-1, -0.5)
 
     def test__rectangular_mask(self):
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [
                     [False, True, True, True],
@@ -1275,7 +1363,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (0, 0)
         assert mask.geometry._zoom_offset_pixels == (-1.0, -1.5)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [
                     [True, True, True, True],
@@ -1289,7 +1377,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (2, 3)
         assert mask.geometry._zoom_offset_pixels == (1.0, 1.5)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [
                     [True, True, True, True, True],
@@ -1303,7 +1391,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (2, 4)
         assert mask.geometry._zoom_offset_pixels == (1, 2)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [
                     [True, True, True, True, True, True, True],
@@ -1317,7 +1405,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (2, 6)
         assert mask.geometry._zoom_offset_pixels == (1, 3)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [
                     [True, True, True],
@@ -1333,7 +1421,7 @@ class TestZoomCentreAndOffet:
         assert mask.geometry._zoom_centre == (4, 2)
         assert mask.geometry._zoom_offset_pixels == (2, 1)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=np.array(
                 [
                     [True, True, True],
