@@ -8,34 +8,32 @@ import autoarray as aa
 from autoarray.mask import mask as msk
 from autoarray import exc
 
-test_data_dir = "{}/../test_files/array/".format(
-    os.path.dirname(os.path.realpath(__file__))
-)
+test_data_dir = "{}/files/mask/".format(os.path.dirname(os.path.realpath(__file__)))
 
 
 class TestMask:
     def test__mask__makes_mask_without_other_inputs(self):
 
-        mask = aa.mask.manual(mask_2d=[[False, False], [False, False]])
+        mask = aa.Mask.manual(mask_2d=[[False, False], [False, False]])
 
         assert type(mask) == msk.Mask
         assert (mask == np.array([[False, False], [False, False]])).all()
 
-        mask = aa.mask.manual(mask_2d=[[False, False, True], [True, True, False]])
+        mask = aa.Mask.manual(mask_2d=[[False, False, True], [True, True, False]])
 
         assert type(mask) == msk.Mask
         assert (mask == np.array([[False, False, True], [True, True, False]])).all()
 
     def test__mask__makes_mask_with_pixel_scale(self):
 
-        mask = aa.mask.manual(mask_2d=[[False, False], [True, True]], pixel_scales=1.0)
+        mask = aa.Mask.manual(mask_2d=[[False, False], [True, True]], pixel_scales=1.0)
 
         assert type(mask) == msk.Mask
         assert (mask == np.array([[False, False], [True, True]])).all()
         assert mask.pixel_scales == (1.0, 1.0)
         assert mask.origin == (0.0, 0.0)
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=[[False, False, True], [True, True, False]],
             pixel_scales=(2.0, 3.0),
             origin=(0.0, 1.0),
@@ -48,7 +46,7 @@ class TestMask:
 
     def test__mask__makes_mask_with_pixel_scale_and_sub_size(self):
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=[[False, False], [True, True]], pixel_scales=1.0, sub_size=1
         )
 
@@ -58,7 +56,7 @@ class TestMask:
         assert mask.origin == (0.0, 0.0)
         assert mask.sub_size == 1
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=[[False, False], [True, True]],
             pixel_scales=(2.0, 3.0),
             sub_size=2,
@@ -71,7 +69,7 @@ class TestMask:
         assert mask.origin == (0.0, 1.0)
         assert mask.sub_size == 2
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=[[False, False], [True, True], [True, False], [False, True]],
             pixel_scales=1.0,
             sub_size=2,
@@ -88,7 +86,7 @@ class TestMask:
 
     def test__mask__invert_is_true_inverts_the_mask(self):
 
-        mask = aa.mask.manual(
+        mask = aa.Mask.manual(
             mask_2d=[[False, False, True], [True, True, False]], invert=True
         )
 
@@ -99,35 +97,35 @@ class TestMask:
 
         with pytest.raises(exc.MaskException):
 
-            aa.mask.manual(mask_2d=[False, False, True])
+            aa.Mask.manual(mask_2d=[False, False, True])
 
         with pytest.raises(exc.MaskException):
 
-            aa.mask.manual(mask_2d=[False, False, True], pixel_scales=False)
+            aa.Mask.manual(mask_2d=[False, False, True], pixel_scales=False)
 
         with pytest.raises(exc.MaskException):
 
-            aa.mask.manual(mask_2d=[False, False, True], sub_size=1)
+            aa.Mask.manual(mask_2d=[False, False, True], sub_size=1)
 
         with pytest.raises(exc.MaskException):
 
-            aa.mask.manual(mask_2d=[False, False, True], pixel_scales=False, sub_size=1)
+            aa.Mask.manual(mask_2d=[False, False, True], pixel_scales=False, sub_size=1)
 
     def test__is_all_false(self):
 
-        mask = aa.mask.manual(mask_2d=[[False, False], [False, False]])
+        mask = aa.Mask.manual(mask_2d=[[False, False], [False, False]])
 
         assert mask.is_all_false == True
 
-        mask = aa.mask.manual(mask_2d=[[False, False]])
+        mask = aa.Mask.manual(mask_2d=[[False, False]])
 
         assert mask.is_all_false == True
 
-        mask = aa.mask.manual(mask_2d=[[False, True], [False, False]])
+        mask = aa.Mask.manual(mask_2d=[[False, True], [False, False]])
 
         assert mask.is_all_false == False
 
-        mask = aa.mask.manual(mask_2d=[[True, True], [False, False]])
+        mask = aa.Mask.manual(mask_2d=[[True, True], [False, False]])
 
         assert mask.is_all_false == False
 
@@ -135,7 +133,7 @@ class TestMask:
 class TestUnmasked:
     def test__mask_all_unmasked__5x5__input__all_are_false(self):
 
-        mask = aa.mask.unmasked(shape_2d=(5, 5), invert=False)
+        mask = aa.Mask.unmasked(shape_2d=(5, 5), invert=False)
 
         assert mask.shape == (5, 5)
         assert (
@@ -151,7 +149,7 @@ class TestUnmasked:
             )
         ).all()
 
-        mask = aa.mask.unmasked(
+        mask = aa.Mask.unmasked(
             shape_2d=(3, 3), pixel_scales=(1.5, 1.5), invert=False, sub_size=2
         )
 
@@ -168,7 +166,7 @@ class TestUnmasked:
         assert mask.origin == (0.0, 0.0)
         assert mask.geometry.mask_centre == (0.0, 0.0)
 
-        mask = aa.mask.unmasked(
+        mask = aa.Mask.unmasked(
             shape_2d=(3, 3),
             pixel_scales=(2.0, 2.5),
             invert=True,
@@ -194,7 +192,7 @@ class TestCircular:
             shape_2d=(5, 4), pixel_scales=(2.7, 2.7), radius=3.5, centre=(0.0, 0.0)
         )
 
-        mask = aa.mask.circular(
+        mask = aa.Mask.circular(
             shape_2d=(5, 4),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
@@ -211,7 +209,7 @@ class TestCircular:
             shape_2d=(5, 4), pixel_scales=(2.7, 2.7), radius=3.5, centre=(0.0, 0.0)
         )
 
-        mask = aa.mask.circular(
+        mask = aa.Mask.circular(
             shape_2d=(5, 4),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
@@ -235,7 +233,7 @@ class TestAnnular:
             centre=(0.0, 0.0),
         )
 
-        mask = aa.mask.circular_annular(
+        mask = aa.Mask.circular_annular(
             shape_2d=(5, 4),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
@@ -257,7 +255,7 @@ class TestAnnular:
             centre=(0.0, 0.0),
         )
 
-        mask = aa.mask.circular_annular(
+        mask = aa.Mask.circular_annular(
             shape_2d=(5, 4),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
@@ -283,7 +281,7 @@ class TestAntiAnnular:
             centre=(0.0, 0.0),
         )
 
-        mask = aa.mask.circular_anti_annular(
+        mask = aa.Mask.circular_anti_annular(
             shape_2d=(9, 9),
             pixel_scales=(1.2, 1.2),
             sub_size=1,
@@ -307,7 +305,7 @@ class TestAntiAnnular:
             centre=(0.0, 0.0),
         )
 
-        mask = aa.mask.circular_anti_annular(
+        mask = aa.Mask.circular_anti_annular(
             shape_2d=(9, 9),
             pixel_scales=(1.2, 1.2),
             sub_size=1,
@@ -334,7 +332,7 @@ class TestElliptical:
             centre=(0.0, 0.0),
         )
 
-        mask = aa.mask.elliptical(
+        mask = aa.Mask.elliptical(
             shape_2d=(8, 5),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
@@ -358,7 +356,7 @@ class TestElliptical:
             centre=(0.0, 0.0),
         )
 
-        mask = aa.mask.elliptical(
+        mask = aa.Mask.elliptical(
             shape_2d=(8, 5),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
@@ -388,7 +386,7 @@ class TestEllipiticalAnnular:
             centre=(0.0, 0.0),
         )
 
-        mask = aa.mask.elliptical_annular(
+        mask = aa.Mask.elliptical_annular(
             shape_2d=(8, 5),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
@@ -419,7 +417,7 @@ class TestEllipiticalAnnular:
             centre=(0.0, 0.0),
         )
 
-        mask = aa.mask.elliptical_annular(
+        mask = aa.Mask.elliptical_annular(
             shape_2d=(8, 5),
             pixel_scales=(2.7, 2.7),
             sub_size=1,
@@ -441,7 +439,7 @@ class TestEllipiticalAnnular:
 class TestFromPixelCoordinates:
     def test__mask_with_or_without_buffer__false_at_buffed_coordinates(self):
 
-        mask = aa.mask.from_pixel_coordinates(
+        mask = aa.Mask.from_pixel_coordinates(
             shape_2d=(5, 5), pixel_coordinates=[[2, 2]], pixel_scales=1.0, buffer=0
         )
 
@@ -458,7 +456,7 @@ class TestFromPixelCoordinates:
             )
         ).all()
 
-        mask = aa.mask.from_pixel_coordinates(
+        mask = aa.Mask.from_pixel_coordinates(
             shape_2d=(5, 5), pixel_coordinates=[[2, 2]], pixel_scales=1.0, buffer=1
         )
 
@@ -475,7 +473,7 @@ class TestFromPixelCoordinates:
             )
         ).all()
 
-        mask = aa.mask.from_pixel_coordinates(
+        mask = aa.Mask.from_pixel_coordinates(
             shape_2d=(7, 7),
             pixel_coordinates=[[2, 2], [5, 5]],
             pixel_scales=1.0,
@@ -508,7 +506,7 @@ class TestFromAndToFits:
             pixel_scales=(1.0, 1.0),
         )
 
-        output_data_dir = "{}/../../test_files/array/output_test/".format(
+        output_data_dir = "{}/files/array/output_test/".format(
             os.path.dirname(os.path.realpath(__file__))
         )
 
@@ -557,35 +555,35 @@ class TestFromAndToFits:
 class TestSubQuantities:
     def test__sub_shape_is_shape_times_sub_size(self):
 
-        mask = aa.mask.unmasked(shape_2d=(5, 5), sub_size=1)
+        mask = aa.Mask.unmasked(shape_2d=(5, 5), sub_size=1)
 
         assert mask.sub_shape_2d == (5, 5)
 
-        mask = aa.mask.unmasked(shape_2d=(5, 5), sub_size=2)
+        mask = aa.Mask.unmasked(shape_2d=(5, 5), sub_size=2)
 
         assert mask.sub_shape_2d == (10, 10)
 
-        mask = aa.mask.unmasked(shape_2d=(10, 5), sub_size=3)
+        mask = aa.Mask.unmasked(shape_2d=(10, 5), sub_size=3)
 
         assert mask.sub_shape_2d == (30, 15)
 
     def test__sub_pixels_in_mask_is_pixels_in_mask_times_sub_size_squared(self):
 
-        mask = aa.mask.unmasked(shape_2d=(5, 5), sub_size=1)
+        mask = aa.Mask.unmasked(shape_2d=(5, 5), sub_size=1)
 
         assert mask.sub_pixels_in_mask == 25
 
-        mask = aa.mask.unmasked(shape_2d=(5, 5), sub_size=2)
+        mask = aa.Mask.unmasked(shape_2d=(5, 5), sub_size=2)
 
         assert mask.sub_pixels_in_mask == 100
 
-        mask = aa.mask.unmasked(shape_2d=(10, 10), sub_size=3)
+        mask = aa.Mask.unmasked(shape_2d=(10, 10), sub_size=3)
 
         assert mask.sub_pixels_in_mask == 900
 
     def test__sub_mask__is_mask_at_sub_grid_resolution(self):
 
-        mask = aa.mask.manual([[False, True], [False, False]], sub_size=2)
+        mask = aa.Mask.manual([[False, True], [False, False]], sub_size=2)
 
         assert (
             mask.sub_mask_2d
@@ -599,7 +597,7 @@ class TestSubQuantities:
             )
         ).all()
 
-        mask = aa.mask.manual([[False, False, True], [False, True, False]], sub_size=2)
+        mask = aa.Mask.manual([[False, False, True], [False, True, False]], sub_size=2)
 
         assert (
             mask.sub_mask_2d
@@ -617,7 +615,7 @@ class TestSubQuantities:
 class TestBinnedMask:
     def test__compare_to_mask_via_util(self):
 
-        mask = aa.mask.unmasked(shape_2d=(14, 19), pixel_scales=(1.0, 1.0))
+        mask = aa.Mask.unmasked(shape_2d=(14, 19), pixel_scales=(1.0, 1.0))
         mask[1, 5] = False
         mask[6, 5] = False
         mask[4, 9] = False
@@ -631,7 +629,7 @@ class TestBinnedMask:
         assert (mask == binned_up_mask_via_util).all()
         assert mask.pixel_scales == (2.0, 2.0)
 
-        mask = aa.mask.unmasked(shape_2d=(14, 19), pixel_scales=(2.0, 2.0))
+        mask = aa.Mask.unmasked(shape_2d=(14, 19), pixel_scales=(2.0, 2.0))
         mask[1, 5] = False
         mask[6, 5] = False
         mask[4, 9] = False
