@@ -8,15 +8,13 @@ class TestVisiblities:
     def test__real_visibilities__intensity_image_all_ones__simple_cases(self):
 
         uv_wavelengths = np.ones(shape=(4, 2))
-        grid_radians = aa.grid.manual_2d([[[1.0, 1.0]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[1.0, 1.0]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
-        image = aa.array.ones(shape_2d=(1, 1))
+        image = aa.Array.ones(shape_2d=(1, 1))
 
         real_visibilities = transformer.real_visibilities_from_image(image=image)
 
@@ -24,20 +22,16 @@ class TestVisiblities:
 
         uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
 
-        grid_radians = aa.grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
-        image = aa.array.ones(shape_2d=(1, 2))
+        image = aa.Array.ones(shape_2d=(1, 2))
 
         real_visibilities = transformer.real_visibilities_from_image(image=image)
 
-        print(real_visibilities)
-
         assert real_visibilities == pytest.approx(
             np.array([-0.091544, -0.73359736, -0.613160]), 1.0e-4
         )
@@ -45,15 +39,13 @@ class TestVisiblities:
     def test__real_visibilities__intensity_image_varies__simple_cases(self):
 
         uv_wavelengths = np.ones(shape=(4, 2))
-        grid_radians = aa.grid.manual_2d([[[1.0, 1.0]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[1.0, 1.0]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
-        image = aa.array.manual_2d([[2.0]])
+        image = aa.Array.manual_2d([[2.0]])
 
         real_visibilities = transformer.real_visibilities_from_image(image=image)
 
@@ -61,15 +53,13 @@ class TestVisiblities:
 
         uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
 
-        grid_radians = aa.grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
-        image = aa.array.manual_2d([[3.0, 6.0]])
+        image = aa.Array.manual_2d([[3.0, 6.0]])
 
         real_visibilities = transformer.real_visibilities_from_image(image=image)
 
@@ -80,20 +70,16 @@ class TestVisiblities:
     def test__real_visibilities__preload_and_non_preload_give_same_answer(self):
 
         uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
-        grid_radians = aa.grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
 
-        transformer_preload = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=True,
+        transformer_preload = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=True
         )
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
-        image = aa.array.manual_2d([[2.0, 6.0]])
+        image = aa.Array.manual_2d([[2.0, 6.0]])
 
         real_visibilities_via_preload = transformer_preload.real_visibilities_from_image(
             image=image
@@ -105,15 +91,13 @@ class TestVisiblities:
     def test__imag_visibilities__intensity_image_all_ones__simple_cases(self):
 
         uv_wavelengths = np.ones(shape=(4, 2))
-        grid_radians = aa.grid.manual_2d([[[1.0, 1.0]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[1.0, 1.0]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
-        image = aa.array.ones(shape_2d=(1, 1))
+        image = aa.Array.ones(shape_2d=(1, 1))
 
         imag_visibilities = transformer.imag_visibilities_from_image(image=image)
 
@@ -121,15 +105,13 @@ class TestVisiblities:
 
         uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
 
-        grid_radians = aa.grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
-        image = aa.array.ones(shape_2d=(2, 1))
+        image = aa.Array.ones(shape_2d=(2, 1))
 
         imag_visibilities = transformer.imag_visibilities_from_image(image=image)
 
@@ -140,15 +122,13 @@ class TestVisiblities:
     def test__imag_visibilities__intensity_image_varies__simple_cases(self):
 
         uv_wavelengths = np.ones(shape=(4, 2))
-        grid_radians = aa.grid.manual_2d([[[1.0, 1.0]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[1.0, 1.0]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
-        image = aa.array.manual_2d([[2.0]])
+        image = aa.Array.manual_2d([[2.0]])
 
         imag_visibilities = transformer.imag_visibilities_from_image(image=image)
 
@@ -156,15 +136,13 @@ class TestVisiblities:
 
         uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
 
-        grid_radians = aa.grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
-        image = aa.array.manual_2d([[3.0, 6.0]])
+        image = aa.Array.manual_2d([[3.0, 6.0]])
 
         imag_visibilities = transformer.imag_visibilities_from_image(image=image)
 
@@ -175,20 +153,16 @@ class TestVisiblities:
     def test__imag_visibilities__preload_and_non_preload_give_same_answer(self):
 
         uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
-        grid_radians = aa.grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
 
-        transformer_preload = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=True,
+        transformer_preload = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=True
         )
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
-        image = aa.array.manual_2d([[2.0, 6.0]])
+        image = aa.Array.manual_2d([[2.0, 6.0]])
 
         imag_visibilities_via_preload = transformer_preload.imag_visibilities_from_image(
             image=image
@@ -201,15 +175,13 @@ class TestVisiblities:
 
         uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
 
-        grid_radians = aa.grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
-        image = aa.array.manual_2d([[3.0, 6.0]])
+        image = aa.Array.manual_2d([[3.0, 6.0]])
 
         visibilities = transformer.visibilities_from_image(image=image)
 
@@ -231,12 +203,10 @@ class TestVisiblitiesMappingMatrix:
     def test__real_visibilities__mapping_matrix_all_ones__simple_cases(self):
 
         uv_wavelengths = np.ones(shape=(4, 2))
-        grid_radians = aa.grid.manual_2d([[[1.0, 1.0]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[1.0, 1.0]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
         mapping_matrix = np.ones(shape=(1, 1))
@@ -249,12 +219,10 @@ class TestVisiblitiesMappingMatrix:
 
         uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
 
-        grid_radians = aa.grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
         mapping_matrix = np.ones(shape=(2, 1))
@@ -263,8 +231,6 @@ class TestVisiblitiesMappingMatrix:
             mapping_matrix=mapping_matrix
         )
 
-        print(transformed_mapping_matrix)
-
         assert transformed_mapping_matrix == pytest.approx(
             np.array([[-0.091544], [-0.733597], [-0.613160]]), 1.0e-4
         )
@@ -284,16 +250,14 @@ class TestVisiblitiesMappingMatrix:
 
     def test__real_visibilities__more_complex_mapping_matrix(self):
 
-        grid_radians = aa.grid.manual_2d(
+        grid_radians = aa.Grid.manual_2d(
             [[[0.1, 0.2], [0.3, 0.4], [0.5, 0.6]]], pixel_scales=1.0
         )
 
         uv_wavelengths = np.array([[0.7, 0.8], [0.9, 1.0]])
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
         mapping_matrix = np.array([[1.0], [0.0], [0.0]])
@@ -312,8 +276,6 @@ class TestVisiblitiesMappingMatrix:
             mapping_matrix=mapping_matrix
         )
 
-        print(transformed_mapping_matrix)
-
         assert transformed_mapping_matrix == pytest.approx(
             np.array([[-0.992111], [-0.53582]]), 1.0e-4
         )
@@ -331,18 +293,14 @@ class TestVisiblitiesMappingMatrix:
     def test__real_visibilities__preload_and_non_preload_give_same_answer(self):
 
         uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
-        grid_radians = aa.grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
 
-        transformer_preload = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=True,
+        transformer_preload = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=True
         )
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
         mapping_matrix = np.array([[3.0, 5.0], [1.0, 2.0]])
@@ -360,12 +318,10 @@ class TestVisiblitiesMappingMatrix:
     def test__imag_visibilities__mapping_matrix_all_ones__simple_cases(self):
 
         uv_wavelengths = np.ones(shape=(4, 2))
-        grid_radians = aa.grid.manual_2d([[[1.0, 1.0]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[1.0, 1.0]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
         mapping_matrix = np.ones(shape=(1, 1))
@@ -380,12 +336,10 @@ class TestVisiblitiesMappingMatrix:
 
         uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
 
-        grid_radians = aa.grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
         mapping_matrix = np.ones(shape=(2, 1))
@@ -413,16 +367,14 @@ class TestVisiblitiesMappingMatrix:
 
     def test__imag_visibilities__more_complex_mapping_matrix(self):
 
-        grid_radians = aa.grid.manual_2d(
+        grid_radians = aa.Grid.manual_2d(
             [[[0.1, 0.2], [0.3, 0.4], [0.5, 0.6]]], pixel_scales=1.0
         )
 
         uv_wavelengths = np.array([[0.7, 0.8], [0.9, 1.0]])
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
         mapping_matrix = np.array([[1.0], [0.0], [0.0]])
@@ -458,18 +410,14 @@ class TestVisiblitiesMappingMatrix:
     def test__imag_visibilities__preload_and_non_preload_give_same_answer(self):
 
         uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
-        grid_radians = aa.grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
 
-        transformer_preload = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=True,
+        transformer_preload = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=True
         )
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
         mapping_matrix = np.array([[3.0, 5.0], [1.0, 2.0]])
@@ -489,12 +437,10 @@ class TestVisiblitiesMappingMatrix:
     ):
 
         uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
-        grid_radians = aa.grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
+        grid_radians = aa.Grid.manual_2d([[[0.1, 0.2], [0.3, 0.4]]], pixel_scales=1.0)
 
-        transformer = aa.transformer(
-            uv_wavelengths=uv_wavelengths,
-            grid_radians=grid_radians,
-            preload_transform=False,
+        transformer = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
         )
 
         mapping_matrix = np.ones(shape=(2, 1))
@@ -509,3 +455,133 @@ class TestVisiblitiesMappingMatrix:
         assert transformed_mapping_matrices[1] == pytest.approx(
             np.array([[-1.45506], [-0.78120], [-0.07746]]), 1.0e-4
         )
+
+
+class TestTransformerFFT:
+    def test__image_from_visibilities__same_as_direct__include_numerics(self):
+
+        uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
+
+        grid_radians = aa.Grid.uniform(shape_2d=(5, 5), pixel_scales=0.005)
+
+        image = aa.Array.ones(
+            shape_2d=grid_radians.shape_2d, pixel_scales=grid_radians.pixel_scales
+        )
+
+        transformer_dft = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
+        )
+
+        visibilities_dft = transformer_dft.visibilities_from_image(image=image.in_2d)
+
+        transformer_fft = aa.TransformerFFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians
+        )
+
+        visibilities_fft = transformer_fft.visibilities_from_image(image=image.in_2d)
+
+        assert visibilities_dft == pytest.approx(visibilities_fft, 1.0e-2)
+
+        assert visibilities_fft[0, 0] == pytest.approx(24.99999646, 1.0e-7)
+
+    def test__mapping_matix_from_visibilities__same_as_direct__include_numerics(self):
+
+        uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
+
+        grid_radians = aa.Grid.uniform(shape_2d=(5, 5), pixel_scales=0.005)
+
+        mapping_matrix = np.ones(shape=(25, 3))
+
+        transformer_dft = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
+        )
+
+        transformed_mapping_matrices_dft = transformer_dft.transformed_mapping_matrices_from_mapping_matrix(
+            mapping_matrix=mapping_matrix
+        )
+
+        transformer_fft = aa.TransformerFFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians
+        )
+
+        transformed_mapping_matrices_fft = transformer_fft.transformed_mapping_matrices_from_mapping_matrix(
+            mapping_matrix=mapping_matrix
+        )
+
+        assert transformed_mapping_matrices_dft[0] == pytest.approx(
+            transformed_mapping_matrices_fft[0], 1.0e-2
+        )
+        assert transformed_mapping_matrices_dft[1] == pytest.approx(
+            transformed_mapping_matrices_fft[1], 1.0e-2
+        )
+
+        assert transformed_mapping_matrices_fft[0][0, 0] == pytest.approx(
+            24.99999636, 1.0e-2
+        )
+        assert transformed_mapping_matrices_fft[1][0, 0] == pytest.approx(0.0, 1.0e-2)
+
+
+class TestTransformerNUFFT:
+    def test__image_from_visibilities__same_as_direct__include_numerics(self):
+
+        uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
+
+        grid_radians = aa.Grid.uniform(shape_2d=(5, 5), pixel_scales=0.005)
+
+        image = aa.Array.ones(
+            shape_2d=grid_radians.shape_2d, pixel_scales=grid_radians.pixel_scales
+        )
+
+        transformer_dft = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
+        )
+
+        visibilities_dft = transformer_dft.visibilities_from_image(image=image.in_2d)
+
+        transformer_nufft = aa.TransformerNUFFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians
+        )
+
+        visibilities_nufft = transformer_nufft.visibilities_from_image(
+            image=image.in_2d
+        )
+
+        assert visibilities_dft == pytest.approx(visibilities_nufft, 1.0e-2)
+
+        assert visibilities_nufft[0, 0] == pytest.approx(25.02317617953263, 1.0e-7)
+
+    def test__mapping_matix_from_visibilities__same_as_direct__include_numerics(self):
+
+        uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
+
+        grid_radians = aa.Grid.uniform(shape_2d=(5, 5), pixel_scales=0.005)
+
+        mapping_matrix = np.ones(shape=(25, 3))
+
+        transformer_dft = aa.TransformerDFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians, preload_transform=False
+        )
+
+        transformed_mapping_matrices_dft = transformer_dft.transformed_mapping_matrices_from_mapping_matrix(
+            mapping_matrix=mapping_matrix
+        )
+
+        transformer_nufft = aa.TransformerNUFFT(
+            uv_wavelengths=uv_wavelengths, grid=grid_radians
+        )
+
+        transformed_mapping_matrices_nufft = transformer_nufft.transformed_mapping_matrices_from_mapping_matrix(
+            mapping_matrix=mapping_matrix
+        )
+
+        assert transformed_mapping_matrices_dft[0] == pytest.approx(
+            transformed_mapping_matrices_nufft[0], 1.0e-2
+        )
+        assert transformed_mapping_matrices_dft[1] == pytest.approx(
+            transformed_mapping_matrices_nufft[1], 1.0e-2
+        )
+
+        assert transformed_mapping_matrices_nufft[0][0, 0] == pytest.approx(
+            24.99999636, 1.0e-2
+        )
+        assert transformed_mapping_matrices_nufft[1][0, 0] == pytest.approx(0.0, 1.0e-2)
