@@ -12,13 +12,13 @@ directory = path.dirname(path.realpath(__file__))
 
 @pytest.fixture(name="plot_path")
 def make_plotter_setup():
-    return "{}/..//test_files/plot/".format(os.path.dirname(os.path.realpath(__file__)))
+    return "{}/files/plotter/".format(os.path.dirname(os.path.realpath(__file__)))
 
 
 @pytest.fixture(autouse=True)
 def set_config_path():
     aa.conf.instance = aa.conf.Config(
-        path.join(directory, "../test_files/plot"), path.join(directory, "output")
+        path.join(directory, "files/plotter"), path.join(directory, "output")
     )
 
 
@@ -563,6 +563,9 @@ class TestAbstractPlotterAttributes:
         assert plotter.output.format == "png"
         assert plotter.output.filename == "file"
 
+        if os.path.exists(plotter.output.path):
+            shutil.rmtree(plotter.output.path)
+
         sub_plotter = aplt.SubPlotter()
 
         assert sub_plotter.output.path == None
@@ -579,20 +582,23 @@ class TestAbstractPlotterAttributes:
         assert sub_plotter.output.format == "png"
         assert sub_plotter.output.filename == "file"
 
+        if os.path.exists(plotter.output.path):
+            shutil.rmtree(plotter.output.path)
+
 
 class TestAbstractPlotterPlots:
     def test__plot_array__works_with_all_extras_included(self, plot_path, plot_patch):
 
-        array = aa.array.ones(shape_2d=(31, 31), pixel_scales=(1.0, 1.0), sub_size=2)
+        array = aa.Array.ones(shape_2d=(31, 31), pixel_scales=(1.0, 1.0), sub_size=2)
 
-        mask = aa.mask.circular(
+        mask = aa.Mask.circular(
             shape_2d=array.shape_2d,
             pixel_scales=array.pixel_scales,
             radius=5.0,
             centre=(2.0, 2.0),
         )
 
-        grid = aa.grid.uniform(shape_2d=(11, 11), pixel_scales=0.5)
+        grid = aa.Grid.uniform(shape_2d=(11, 11), pixel_scales=0.5)
 
         plotter = aplt.Plotter(
             output=aplt.Output(path=plot_path, filename="array1", format="png")
@@ -626,7 +632,7 @@ class TestAbstractPlotterPlots:
 
         assert plot_path + "array2.png" in plot_patch.paths
 
-        aplt.array(
+        aplt.Array(
             array=array,
             mask=mask,
             grid=grid,
@@ -647,7 +653,7 @@ class TestAbstractPlotterPlots:
         if os.path.exists(plot_path):
             shutil.rmtree(plot_path)
 
-        arr = aa.array.ones(shape_2d=(31, 31), pixel_scales=(1.0, 1.0), sub_size=2)
+        arr = aa.Array.ones(shape_2d=(31, 31), pixel_scales=(1.0, 1.0), sub_size=2)
 
         plotter = aplt.Plotter(
             output=aplt.Output(path=plot_path, filename="array", format="fits")
@@ -661,11 +667,11 @@ class TestAbstractPlotterPlots:
 
         assert (arr == np.ones(shape=(31, 31))).all()
 
-        mask = aa.mask.circular(
+        mask = aa.Mask.circular(
             shape_2d=(31, 31), pixel_scales=(1.0, 1.0), radius=5.0, centre=(2.0, 2.0)
         )
 
-        masked_array = aa.masked_array.manual_2d(array=arr, mask=mask)
+        masked_array = aa.MaskedArray.manual_2d(array=arr, mask=mask)
 
         plotter.plot_array(array=masked_array)
 
@@ -676,7 +682,7 @@ class TestAbstractPlotterPlots:
         assert arr.shape == (13, 13)
 
     def test__plot_grid__works_with_all_extras_included(self, plot_path, plot_patch):
-        grid = aa.grid.uniform(shape_2d=(11, 11), pixel_scales=1.0)
+        grid = aa.Grid.uniform(shape_2d=(11, 11), pixel_scales=1.0)
         color_array = np.linspace(start=0.0, stop=1.0, num=grid.shape_1d)
 
         plotter = aplt.Plotter(
@@ -709,7 +715,7 @@ class TestAbstractPlotterPlots:
 
         assert plot_path + "grid2.png" in plot_patch.paths
 
-        aplt.grid(
+        aplt.Grid(
             grid=grid,
             color_array=color_array,
             axis_limits=[-1.5, 1.5, -2.5, 2.5],
@@ -755,7 +761,7 @@ class TestAbstractPlotterPlots:
 
         assert plot_path + "line2.png" in plot_patch.paths
 
-        aplt.line(
+        aplt.Line(
             y=np.array([1.0, 2.0, 3.0]),
             x=np.array([0.5, 1.0, 1.5]),
             plot_axis_type="loglog",
@@ -803,7 +809,7 @@ class TestAbstractPlotterPlots:
 
         assert plot_path + "mapper2.png" in plot_patch.paths
 
-        aplt.mapper_obj(
+        aplt.MapperObj(
             mapper=rectangular_mapper_7x7_3x3,
             include=aplt.Include(
                 inversion_pixelization_grid=True,
@@ -853,7 +859,7 @@ class TestAbstractPlotterPlots:
 
         assert plot_path + "mapper2.png" in plot_patch.paths
 
-        aplt.mapper_obj(
+        aplt.MapperObj(
             mapper=voronoi_mapper_9_3x3,
             include=aplt.Include(
                 inversion_pixelization_grid=True,
@@ -968,13 +974,22 @@ class TestAbstractPlotterNew:
         assert plotter.output.format == "png"
         assert plotter.output.filename == "file"
 
+        if os.path.exists(plotter.output.path):
+            shutil.rmtree(plotter.output.path)
+
         plotter = plotter.plotter_with_new_output(path="Path0", filename="file0")
 
+        if os.path.exists(plotter.output.path):
+            shutil.rmtree(plotter.output.path)
+
         assert plotter.output.path == "Path0"
         assert plotter.output._format == "png"
         assert plotter.output.format == "png"
         assert plotter.output.filename == "file0"
 
+        if os.path.exists(plotter.output.path):
+            shutil.rmtree(plotter.output.path)
+
         plotter = plotter.plotter_with_new_output(
             path="Path1", filename="file1", format="fits"
         )
@@ -984,6 +999,9 @@ class TestAbstractPlotterNew:
         assert plotter.output.format == "fits"
         assert plotter.output.filename == "file1"
 
+        if os.path.exists(plotter.output.path):
+            shutil.rmtree(plotter.output.path)
+
     def test__plotter_with_new_units__new_outputs_are_setup_correctly_if_input(self):
 
         plotter = aplt.Plotter(
